/* Copyright 2006, freshmowed software.  All rights reserved. */

/* Example XML
<dataSetInfo xmlns:fmctbt="http://www.freshmowed.com/namespaces/countabout">
<trackerDataSet id="5678876678987">
    <trackerInfo>
        <title>Calories Consumed</title>
        <units>kcal</units>
        <minX>12344</minX>
        <maxX>12355</maxX>
    </trackerInfo>
    <trackerInfo>
    </trackerInfo>
    <trackerInfo>
    </trackerInfo>
</trackerDataSet>
<trackerDataSet id="1678834437">
    <trackerInfo>
    <title>Cycling</title>
    <units>hours</units>
    </trackerInfo>
    <trackerInfo>
    </trackerInfo>
</trackerDataSet>
<trackerDataSet id="2345433223">
     <trackerInfo>
     </trackerInfo>
     <trackerInfo>
     </trackerInfo>
 </trackerDataSet>
 </dataSetInfo>
*/

DataSetInfo = function()
{
    this.trackerDataSets = new Array();
}

DataSetInfo.prototype =
{
    extractFromDOM: function(XMLDOMObject)
    {        
        var aDOM = XMLDOMObject.getElementsByTagName("dataSetInfo");
        if ( aDOM != null )
        {
          var countaboutDOM = aDOM.item(0);
          
          var dataSets = countaboutDOM.getElementsByTagName("trackerDataSet");
            
          if ( dataSets == null || dataSets.length == 0 ) return this;
            
          for ( iDS = 0; iDS < dataSets.length; iDS++ )
          {
              var anElement = dataSets.item(iDS).getAttributeNode("id");
              var anID = anElement ? anElement.nodeValue : null;
              
              if ( anID == null )
              {
                  alert("DataSetInfo extractFromDOM: no id attribute for trackerDataSet");
                  continue;
              }
              
              var aDataSet = new TrackerDataSet(anID)
              this.trackerDataSets.push(aDataSet);
              aDataSet.extractFromDOM(dataSets.item(iDS));
          }

        }
        else
        {
          alert("DataSetInfo.extractFromDOM: unknown XML format.")
        }
            
        return this;
    },

    
    fromXML: function(xml)
    {
      var parser = new DOMImplementation();
      this.extractFromDOM(parser.loadXML(xml));
    },

    sampleXML: function()
    {
        return       "<dataSetInfo xmlns='http://www.freshmowed.com/namespaces/countabout'>\n" +
        "<trackerDataSet id=\"5678876678987\">\n" +
        "<trackerInfo>\n" +
        "<title>Weight</title>\n" + 
        "<units prefix=\"false\">lbs</units>\n" +
        "<minX>12344</minX>\n" +
        "<maxX>12355</maxX>\n" +
        "</trackerInfo>\n" +
        "<trackerInfo>\n" + 
        "<title>Calories</title>\n" + 
        "<units prefix=\"false\">kcal</units>\n" +
        "<minX>12344</minX>\n" +
        "<maxX>12355</maxX>\n" +
        "</trackerInfo>\n" +
        "<trackerInfo>\n" + 
        "<title>Carbohydrates</title>\n" + 
        "<units prefix=\"false\">carbs</units>\n" +
        "<minX>12344</minX>\n" +
        "<maxX>12355</maxX>\n" +
        "</trackerInfo>\n" +
        "</trackerDataSet>\n" +
        "<trackerDataSet id=\"123887667123\">\n" +
        "<trackerInfo>\n" +
        "<title>Weight</title>\n" + 
        "<units prefix=\"false\">lbs</units>\n" +
        "<minX>12344</minX>\n" +
        "<maxX>12355</maxX>\n" +
        "</trackerInfo>\n" +
        "</trackerDataSet>\n" +
        "</dataSetInfo>\n";

    }
}

TrackerDataSet = function(anID)
{
    this.ID = anID;
    this.trackers = new Array();
}

TrackerDataSet.prototype =
{
    extractFromDOM: function(XMLDOMObject)
    {
        var trackerElements = XMLDOMObject.getElementsByTagName("trackerInfo");
        if ( trackerElements == null || trackerElements.length == 0 ) return this;
        
        for ( iTE = 0; iTE < trackerElements.length; iTE++ )
        {
            var aTrackerInfo = new TrackerInfo()
            aTrackerInfo.extractFromDOM(trackerElements.item(iTE));
            this.trackers.push(aTrackerInfo);
        }
                
        return this;
    }
};


TrackerInfo = function()
{
    this.title = "-";
    this.units = "";
    this.numPoints = 0;
    this.minX = null;
    this.maxX = null;
    this.startDate = null;
    this.endDate = null;
}

TrackerInfo.prototype =
{
  extractFromDOM: function(XMLDOMObject)
  {
      var anElement = XMLDOMObject.getElementsByTagName("title");
      this.title = (anElement && anElement.length > 0 && anElement.item(0).firstChild) ? anElement.item(0).firstChild.nodeValue : "";
      
      anElement = XMLDOMObject.getElementsByTagName("minX");
      this.minX = (anElement && anElement.length > 0 && anElement.item(0).firstChild) ? anElement.item(0).firstChild.nodeValue : "";
      
      anElement = XMLDOMObject.getElementsByTagName("maxX");
      this.maxX = (anElement && anElement.length > 0 && anElement.item(0).firstChild) ? anElement.item(0).firstChild.nodeValue : "";

      if ( this.minX != null )
      {
          var aUTC = Utilities.dateFromDaysSinceEpoch(Math.floor(this.minX));
          this.startDate = Utilities.formattedDateString(aUTC, null);
      }
      
      if ( this.maxX != null )
      {
          var aUTC = Utilities.dateFromDaysSinceEpoch(Math.floor(this.maxX));
          this.endDate = Utilities.formattedDateString(aUTC, null);
      }
      
      anElement = XMLDOMObject.getElementsByTagName("numPoints");
      this.numPoints = (anElement && anElement.length > 0 && anElement.item(0).firstChild) ? anElement.item(0).firstChild.nodeValue : 0;
      
      var nodes = XMLDOMObject.getElementsByTagName("units");
      if ( nodes && nodes.length > 0 )
      {
          var unitsNode = nodes.item(0);
          this.units = unitsNode.firstChild ? unitsNode.firstChild.nodeValue : null;
      }
      else
      {
          this.units = "";
      }
      
    return this;
  }
    
};

